==> order-center-domain-2.9.0-CLOUD-DEV-20220818.103646-18-sources.jar: com/tydic/dyc/oc/service/domainservice/UocTacheButtonQryServiceImpl.java <==
package com.tydic.dyc.oc.service.domainservice;

import cn.hutool.core.convert.Convert;
import com.tydic.dyc.base.exception.BaseBusinessException;
import com.tydic.dyc.oc.constants.UocDicConstant;
import com.tydic.dyc.oc.constants.UocRspConstants;
import com.tydic.dyc.oc.model.order.IUocOrderModel;
import com.tydic.dyc.oc.model.order.qrybo.UocOrderTaskInstQryBo;
import com.tydic.dyc.oc.model.order.qrybo.UocTacheButtonQryBo;
import com.tydic.dyc.oc.model.order.sub.UocOrderTaskInst;
import com.tydic.dyc.oc.model.order.sub.UocTacheButton;
import com.tydic.dyc.oc.service.domainservice.bo.UocTacheButtonInfoBO;
import com.tydic.dyc.oc.service.domainservice.bo.UocTacheButtonQryReqBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocTacheButtonQryRspBo;
import com.tydic.dyc.oc.utils.UocRu;
import lombok.extern.ohaotian.HTServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.CollectionUtils;

import java.util.List;
import java.util.concurrent.ConcurrentMap;
import java.util.stream.Collectors;

/**
 * 标题：UocTacheButtonQryServiceImpl
 * 说明：页签环节按钮查询
 * 时间：2022/4/21 15:01
 *
 * @author 文乐
 */
@HTServiceImpl
public class UocTacheButtonQryServiceImpl implements UocTacheButtonQryService {

    @Autowired
    private IUocOrderModel iUocOrderModel;

    public static final String DEFAULT = "DEFAULT";

    //反射controller调用地址
    @Value("${button.url.prefix:http://39.96.39.0/lowCode/}")
    private String BUTTON_URL_PREFIX;

    //非反射controller调用地址
    @Value("${button.url.prefix.real:http://39.96.39.0/lowCodeRelease/#/}")
    private String BUTTON_URL_PREFIX_REAL;

    @Override
    public UocTacheButtonQryRspBo qryTacheButton(UocTacheButtonQryReqBo reqBo) {
        validateArg(reqBo);
        UocTacheButtonQryRspBo rspBo = UocRu.success(UocTacheButtonQryRspBo.class);
        UocTacheButtonQryBo uocTacheButtonQryBo = new UocTacheButtonQryBo();
        uocTacheButtonQryBo.setTabId(Convert.toInt(reqBo.getTabId()));
        uocTacheButtonQryBo.setTacheCodes(reqBo.getTacheCodes());
        // 默认传一个ALL
        uocTacheButtonQryBo.getTacheCodes().add(DEFAULT);
        uocTacheButtonQryBo.setSubOrderStatusCodes(reqBo.getSubOrderStatusCodes());
        uocTacheButtonQryBo.setOrderStatusList(reqBo.getOrderStatusList());
//        uocTacheButtonQryBo.setOrderBy("id");
        List<UocTacheButton> uocTacheButtons = iUocOrderModel.qryTacheButton(uocTacheButtonQryBo);

        List<UocTacheButtonInfoBO> uocTacheButtonInfoBOS = UocRu.jsl(uocTacheButtons, UocTacheButtonInfoBO.class);
        List<String> formTacheCodeList = uocTacheButtonInfoBOS.stream().map(UocTacheButtonInfoBO::getFormTacheCode).collect(Collectors.toList());
        if (!CollectionUtils.isEmpty(formTacheCodeList)) {
            UocOrderTaskInstQryBo uocOrderTaskInstQryBo = new UocOrderTaskInstQryBo();
            uocOrderTaskInstQryBo.setOrderIdList(reqBo.getOrderIdList());
            uocOrderTaskInstQryBo.setObjIdList(reqBo.getObjIdList());
            uocOrderTaskInstQryBo.setObjType(reqBo.getObjType());
            uocOrderTaskInstQryBo.setProcStateList(formTacheCodeList);
            uocOrderTaskInstQryBo.setFinishTag(UocDicConstant.PROC_TASK_FINISHED.NO_FINISHED);
            uocOrderTaskInstQryBo.setOrderBy("create_time desc");
            List<UocOrderTaskInst> uocOrderTaskInsts = iUocOrderModel.qryOrderTaskInstList(uocOrderTaskInstQryBo);
            if (!CollectionUtils.isEmpty(uocOrderTaskInsts)) {
                ConcurrentMap<String, List<UocOrderTaskInst>> tacheCodeMap = uocOrderTaskInsts.stream().collect(Collectors.groupingByConcurrent(UocOrderTaskInst::getProcState));
                uocTacheButtonInfoBOS.forEach(uocTacheButtonInfoBO -> {
                    if (StringUtils.isNotBlank(uocTacheButtonInfoBO.getFormTacheCode())) {
                        List<UocOrderTaskInst> formTaskList = tacheCodeMap.get(uocTacheButtonInfoBO.getFormTacheCode());
                        if (!CollectionUtils.isEmpty(formTaskList)) {
                            if (StringUtils.isNotBlank(formTaskList.get(0).getFormUrl())) {
                                String url = "";
                                //如果是反射调用，取反射地址，加上form url
                                if(reqBo.getReflected() != null && reqBo.getReflected()){
                                    url = BUTTON_URL_PREFIX + formTaskList.get(0).getFormUrl();
                                }else{
                                    //非反射，取非反射地址，同时把后面的 .html 去掉（.html默认在流程中心都配了）
                                    String fromUrl = formTaskList.get(0).getFormUrl();
                                    if(fromUrl.contains(".html")){
                                        fromUrl = fromUrl.substring(0,fromUrl.length() - 5);
                                    }
                                    url = BUTTON_URL_PREFIX_REAL + fromUrl;
                                }
//                                String url = BUTTON_URL_PREFIX + formTaskList.get(0).getFormUrl();
                                if (StringUtils.isNotBlank(uocTacheButtonInfoBO.getFormParam())) {
                                    uocTacheButtonInfoBO.setUri(url + "?" + uocTacheButtonInfoBO.getFormParam());
                                } else {
                                    uocTacheButtonInfoBO.setUri(url);
                                }
                            }
                        }
                    }
                });

            }
        }

        rspBo.setUocTacheButtonS(uocTacheButtonInfoBOS);

//        Map<String, List<UocTacheButton>> tacheCodeMap = uocTacheButtons.stream().collect(Collectors.groupingBy(UocTacheButton::getTacheCode));
//        Map<String, List<UocTacheButton>> subTacheCodeMap = uocTacheButtons.stream()
//                .filter(uocTacheButton -> StringUtils.isNotBlank(uocTacheButton.getSubOrderStatusCode()))
//                .collect(Collectors.groupingBy(UocTacheButton::getSubOrderStatusCode));
//
//        Map<String, List<UocButtonBo>> buttonMap = new HashMap<>(16);
//
//        tacheCodeMap.forEach((tacheCode, uocTacheButtonBoList) -> {
//            List<UocButtonBo> uocButtonBos = uocTacheButtonBoList.stream().map(uocTacheButtonBo -> {
//                UocButtonBo uocButtonBo = new UocButtonBo();
//                uocButtonBo.setMenuCode(uocTacheButtonBo.getMenuCode());
//                uocButtonBo.setMenuDesc(uocTacheButtonBo.getMenuDesc());
//                return uocButtonBo;
//            }).collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(UocButtonBo::getMenuCode))), ArrayList::new));
//            buttonMap.put(tacheCode, uocButtonBos);
//        });
//
//        subTacheCodeMap.forEach((tacheCode, uocTacheButtonBoList) -> {
//            List<UocButtonBo> uocButtonBos = uocTacheButtonBoList.stream().map(uocTacheButtonBo -> {
//                UocButtonBo uocButtonBo = new UocButtonBo();
//                uocButtonBo.setMenuCode(uocTacheButtonBo.getMenuCode());
//                uocButtonBo.setMenuDesc(uocTacheButtonBo.getMenuDesc());
//                return uocButtonBo;
//            }).collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(UocButtonBo::getMenuCode))), ArrayList::new));
//            buttonMap.put(tacheCode, uocButtonBos);
//        });

        return rspBo;
    }

    private void validateArg(UocTacheButtonQryReqBo reqBo) {
        if (StringUtils.isBlank(reqBo.getTabId())) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_ARG_EMPTY_ERROR, "入参tabId不能为空");
        }
//        if (CollectionUtils.isEmpty(reqBo.getTacheCodes())) {
//            throw new BaseBusinessException(UocRspConstants.RSP_CODE_ARG_EMPTY_ERROR, "入参tabId不能为空");
//        }
    }
}

==> order-center-domain-3.0.0-CLOUD-DEV-20250916.095233-183-sources.jar: com/tydic/dyc/oc/service/domainservice/UocTacheButtonQryServiceImpl.java <==
package com.tydic.dyc.oc.service.domainservice;

import cn.hutool.core.convert.Convert;
import com.tydic.dyc.base.exception.BaseBusinessException;
import com.tydic.dyc.oc.constants.UocDicConstant;
import com.tydic.dyc.oc.constants.UocRspConstants;
import com.tydic.dyc.oc.model.order.IUocOrderModel;
import com.tydic.dyc.oc.model.order.qrybo.UocOrderTaskInstQryBo;
import com.tydic.dyc.oc.model.order.qrybo.UocTacheButtonQryBo;
import com.tydic.dyc.oc.model.order.sub.UocOrderTaskInst;
import com.tydic.dyc.oc.model.order.sub.UocTacheButton;
import com.tydic.dyc.oc.service.domainservice.bo.UocTacheButtonInfoBO;
import com.tydic.dyc.oc.service.domainservice.bo.UocTacheButtonQryReqBo;
import com.tydic.dyc.oc.service.domainservice.bo.UocTacheButtonQryRspBo;
import com.tydic.dyc.oc.utils.UocRu;
import lombok.extern.ohaotian.HTServiceImpl;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.util.CollectionUtils;

import java.util.List;
import java.util.concurrent.ConcurrentMap;
import java.util.stream.Collectors;

/**
 * 标题：UocTacheButtonQryServiceImpl
 * 说明：页签环节按钮查询
 * 时间：2022/4/21 15:01
 *
 * @author 文乐
 */
@HTServiceImpl
public class UocTacheButtonQryServiceImpl implements UocTacheButtonQryService {

    @Autowired
    private IUocOrderModel iUocOrderModel;

    public static final String DEFAULT = "DEFAULT";

    //反射controller调用地址
    @Value("${button.url.prefix:http://39.96.39.0/lowCode/}")
    private String BUTTON_URL_PREFIX;

    //非反射controller调用地址
    @Value("${button.url.prefix.real:http://39.96.39.0/lowCodeRelease/#/}")
    private String BUTTON_URL_PREFIX_REAL;

    @Override
    public UocTacheButtonQryRspBo qryTacheButton(UocTacheButtonQryReqBo reqBo) {
        validateArg(reqBo);
        UocTacheButtonQryRspBo rspBo = UocRu.success(UocTacheButtonQryRspBo.class);
        UocTacheButtonQryBo uocTacheButtonQryBo = new UocTacheButtonQryBo();
        uocTacheButtonQryBo.setTabId(Convert.toInt(reqBo.getTabId()));
        uocTacheButtonQryBo.setTacheCodes(reqBo.getTacheCodes());
        // 默认传一个ALL
        uocTacheButtonQryBo.getTacheCodes().add(DEFAULT);
        uocTacheButtonQryBo.setSubOrderStatusCodes(reqBo.getSubOrderStatusCodes());
        uocTacheButtonQryBo.setOrderStatusList(reqBo.getOrderStatusList());
        uocTacheButtonQryBo.setOrderBy("id");
        uocTacheButtonQryBo.setSysTenantId(reqBo.getSysTenantId());
        List<UocTacheButton> uocTacheButtons = iUocOrderModel.qryTacheButton(uocTacheButtonQryBo);

        List<UocTacheButtonInfoBO> uocTacheButtonInfoBOS = UocRu.jsl(uocTacheButtons, UocTacheButtonInfoBO.class);
        List<String> formTacheCodeList = uocTacheButtonInfoBOS.stream().map(UocTacheButtonInfoBO::getFormTacheCode).collect(Collectors.toList());
        if (!CollectionUtils.isEmpty(formTacheCodeList)) {
            UocOrderTaskInstQryBo uocOrderTaskInstQryBo = new UocOrderTaskInstQryBo();
            uocOrderTaskInstQryBo.setOrderIdList(reqBo.getOrderIdList());
            uocOrderTaskInstQryBo.setObjIdList(reqBo.getObjIdList());
            uocOrderTaskInstQryBo.setObjType(reqBo.getObjType());
            uocOrderTaskInstQryBo.setProcStateList(formTacheCodeList);
            uocOrderTaskInstQryBo.setFinishTag(UocDicConstant.PROC_TASK_FINISHED.NO_FINISHED);
            uocOrderTaskInstQryBo.setOrderBy("create_time desc");
            uocOrderTaskInstQryBo.setSysTenantId(reqBo.getSysTenantId());
            List<UocOrderTaskInst> uocOrderTaskInsts = iUocOrderModel.qryOrderTaskInstList(uocOrderTaskInstQryBo);
            if (!CollectionUtils.isEmpty(uocOrderTaskInsts)) {
                ConcurrentMap<String, List<UocOrderTaskInst>> tacheCodeMap = uocOrderTaskInsts.stream().collect(Collectors.groupingByConcurrent(UocOrderTaskInst::getProcState));
                uocTacheButtonInfoBOS.forEach(uocTacheButtonInfoBO -> {
                    if (StringUtils.isNotBlank(uocTacheButtonInfoBO.getFormTacheCode())) {
                        List<UocOrderTaskInst> formTaskList = tacheCodeMap.get(uocTacheButtonInfoBO.getFormTacheCode());
                        if (!CollectionUtils.isEmpty(formTaskList)) {
                            if (StringUtils.isNotBlank(formTaskList.get(0).getFormUrl())) {
                                String url = "";
                                //如果是反射调用，取反射地址，加上form url
                                if(reqBo.getReflected() != null && reqBo.getReflected()){
                                    url = BUTTON_URL_PREFIX + formTaskList.get(0).getFormUrl();
                                }else{
                                    //非反射，取非反射地址，同时把后面的 .html 去掉（.html默认在流程中心都配了）
                                    String fromUrl = formTaskList.get(0).getFormUrl();
                                    if(fromUrl.contains(".html")){
                                        fromUrl = fromUrl.substring(0,fromUrl.length() - 5);
                                    }
                                    url = BUTTON_URL_PREFIX_REAL + fromUrl;
                                }
//                                String url = BUTTON_URL_PREFIX + formTaskList.get(0).getFormUrl();
                                if (StringUtils.isNotBlank(uocTacheButtonInfoBO.getFormParam())) {
                                    uocTacheButtonInfoBO.setUri(url + "?" + uocTacheButtonInfoBO.getFormParam());
                                } else {
                                    uocTacheButtonInfoBO.setUri(url);
                                }
                            }
                        }
                    }
                });

            }
        }

        rspBo.setUocTacheButtonS(uocTacheButtonInfoBOS);

//        Map<String, List<UocTacheButton>> tacheCodeMap = uocTacheButtons.stream().collect(Collectors.groupingBy(UocTacheButton::getTacheCode));
//        Map<String, List<UocTacheButton>> subTacheCodeMap = uocTacheButtons.stream()
//                .filter(uocTacheButton -> StringUtils.isNotBlank(uocTacheButton.getSubOrderStatusCode()))
//                .collect(Collectors.groupingBy(UocTacheButton::getSubOrderStatusCode));
//
//        Map<String, List<UocButtonBo>> buttonMap = new HashMap<>(16);
//
//        tacheCodeMap.forEach((tacheCode, uocTacheButtonBoList) -> {
//            List<UocButtonBo> uocButtonBos = uocTacheButtonBoList.stream().map(uocTacheButtonBo -> {
//                UocButtonBo uocButtonBo = new UocButtonBo();
//                uocButtonBo.setMenuCode(uocTacheButtonBo.getMenuCode());
//                uocButtonBo.setMenuDesc(uocTacheButtonBo.getMenuDesc());
//                return uocButtonBo;
//            }).collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(UocButtonBo::getMenuCode))), ArrayList::new));
//            buttonMap.put(tacheCode, uocButtonBos);
//        });
//
//        subTacheCodeMap.forEach((tacheCode, uocTacheButtonBoList) -> {
//            List<UocButtonBo> uocButtonBos = uocTacheButtonBoList.stream().map(uocTacheButtonBo -> {
//                UocButtonBo uocButtonBo = new UocButtonBo();
//                uocButtonBo.setMenuCode(uocTacheButtonBo.getMenuCode());
//                uocButtonBo.setMenuDesc(uocTacheButtonBo.getMenuDesc());
//                return uocButtonBo;
//            }).collect(Collectors.collectingAndThen(Collectors.toCollection(() -> new TreeSet<>(Comparator.comparing(UocButtonBo::getMenuCode))), ArrayList::new));
//            buttonMap.put(tacheCode, uocButtonBos);
//        });

        return rspBo;
    }

    private void validateArg(UocTacheButtonQryReqBo reqBo) {
        if (StringUtils.isBlank(reqBo.getTabId())) {
            throw new BaseBusinessException(UocRspConstants.RSP_CODE_ARG_EMPTY_ERROR, "入参tabId不能为空");
        }
//        if (CollectionUtils.isEmpty(reqBo.getTacheCodes())) {
//            throw new BaseBusinessException(UocRspConstants.RSP_CODE_ARG_EMPTY_ERROR, "入参tabId不能为空");
//        }
    }
}
